#include "myevent.h"
#include <cairomm/context.h>
#include <gtkmm/label.h>
#include <iostream>

constexpr int area_side(200);

MyArea::MyArea(): empty(false)
{
	set_content_width(area_side);
	set_content_height(area_side);
	
	set_draw_func(sigc::mem_fun(*this, &MyArea::on_draw));
}

MyArea::~MyArea()
{
}

void MyArea::clear()
{
	empty = true; 
	queue_draw();
}

void MyArea::draw()
{
	empty = false;
	queue_draw();
}

void MyArea::on_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height)
{
	if(not empty)
	{
		// coordinates for the center of the window
		int xc, yc;
		xc = width / 2;
		yc = height / 2;

		cr->set_line_width(10.0);

		// draw red lines out from the center of the window
		cr->set_source_rgb(0.8, 0.0, 0.0);
		cr->move_to(0, 0);
		cr->line_to(xc, yc);
		cr->line_to(0, height);
		cr->move_to(xc, yc);
		cr->line_to(width, yc);
		cr->stroke();
	}
	else
	{
		std::cout << "Empty !" << std::endl;
	}
}

MyEvent::MyEvent():
	m_Main_Box(Gtk::Orientation::VERTICAL, 0),
	m_Buttons_Box(Gtk::Orientation::HORIZONTAL, 2),
	m_Button_Clear("Clear"),
	m_Button_Draw("Draw")
{
	set_title("DrawingArea");
	set_resizable(false);
	set_child(m_Main_Box);

	m_Main_Box.append(m_Area);
	m_Main_Box.append(m_Buttons_Box);
	
	m_Buttons_Box.append(m_Button_Clear);
	m_Buttons_Box.append(m_Button_Draw);
	
	m_Button_Clear.signal_clicked().connect(
		sigc::mem_fun(*this, &MyEvent::on_button_clicked_clear));
		
    m_Button_Draw.signal_clicked().connect(
		sigc::mem_fun(*this, &MyEvent::on_button_clicked_draw));
}

void MyEvent::on_button_clicked_clear()
{
	std::cout << "Clear" << std::endl;
	m_Area.clear();
}

void MyEvent::on_button_clicked_draw()
{
	std::cout << "Draw" << std::endl;
	m_Area.draw();
}
